/*
 * Copyright 2021 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.tomcat.vestige.launcher.webresources;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;

import fr.gaellalire.vestige.spi.resolver.VestigeJar;

/**
 * @author Gael Lalire
 */
public class VestigeJarConnection extends URLConnection {

    private VestigeJar vestigeJar;
    
    public VestigeJarConnection(URL url, VestigeJar vestigeJar) {
        super(url);
        this.vestigeJar = vestigeJar;
    }

    @Override
    public void connect() throws IOException {
    }
    
    @Override
    public InputStream getInputStream() throws IOException {
        return vestigeJar.open();
    }
    
    public String getName() {
        return vestigeJar.getName();
    }
    
    @Override
    public long getContentLengthLong() {
        return vestigeJar.getSize();
    }
    
    @Override
    public long getLastModified() {
        return vestigeJar.getLastModified();
    }
    
}
