/*
 * Copyright 2021 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.tomcat.vestige.launcher.webresources;

import java.io.IOException;
import java.io.InputStream;
import java.security.cert.Certificate;

import fr.gaellalire.vestige.spi.resolver.VestigeJar;
import fr.gaellalire.vestige.spi.resolver.VestigeJarEntry;

/**
 * @author Gael Lalire
 */
public class VestigeJarEntryFromVestigeJar implements VestigeJarEntry {

    private VestigeJar parentVestigeJar;
    
    private String entryName;
    
    private VestigeJar entryVestigeJar;

    public VestigeJarEntryFromVestigeJar(VestigeJar parentVestigeJar, String entryName, VestigeJar vestigeJar) {
        this.parentVestigeJar = parentVestigeJar;
        this.entryName = entryName;
        this.entryVestigeJar = vestigeJar;
    }

    @Override
    public long getSize() {
        return entryVestigeJar.getSize();
    }

    @Override
    public InputStream open() throws IOException {
        return entryVestigeJar.open();
    }

    @Override
    public boolean isDirectory() {
        return false;
    }

    @Override
    public long getModificationTime() {
        return entryVestigeJar.getLastModified();
    }

    @Override
    public String getName() {
        return entryName;
    }

    public VestigeJar getVestigeJar() {
        return parentVestigeJar;
    }
    
    public VestigeJar getEntryVestigeJar() {
        return entryVestigeJar;
    }

    @Override
    public Certificate[] getCertificates() {
        return null;
    }

}
