/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tomcat.util.scan;

import java.io.IOException;
import java.net.URL;

import org.apache.tomcat.Jar;

public final class TomcatUtilScanControllerHandler {

    public static final ThreadLocal<TomcatUtilScanController> TOMCAT_CONTROLLER_THREAD_LOCAL = new InheritableThreadLocal<TomcatUtilScanController>();

    public static final TomcatUtilScanController DEFAULT_TOMCAT_CONTROLLER = new TomcatUtilScanController() {

        @Override
        public Jar specificNewInstance(URL url) throws IOException {
            return null;
        }

        @Override
        public String getJarName(URL url) {
            return null;
        }

        @Override
        public URL getJarEntryURL(URL baseUrl, String entryName) {
            return null;
        }

    };

    private TomcatUtilScanControllerHandler() {
    }

    public static void setTomcatController(TomcatUtilScanController tomcatController) {
        TOMCAT_CONTROLLER_THREAD_LOCAL.set(tomcatController);
    }

    public static TomcatUtilScanController getTomcatController() {
        TomcatUtilScanController tomcatController = TOMCAT_CONTROLLER_THREAD_LOCAL.get();
        if (tomcatController == null) {
            return DEFAULT_TOMCAT_CONTROLLER;
        }
        return tomcatController;
    }
}
