/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tomcat.util.scan;

import java.io.IOException;
import java.net.JarURLConnection;
import java.net.URL;
import java.net.URLConnection;

/**
 * Implementation of {@link org.apache.tomcat.Jar} that is optimised for
 * non-file based JAR URLs.
 */
public class UrlJar extends AbstractInputStreamJar {

    public UrlJar(URL jarFileURL) {
        super(jarFileURL);
    }

    @Override
    public void close() {
        closeStream();
    }

    @Override
    protected NonClosingJarInputStream createJarInputStream() throws IOException {
        URLConnection urlConnection = getJarFileURL().openConnection();
        if (urlConnection instanceof JarURLConnection) {
            JarURLConnection jarConn = (JarURLConnection) urlConnection;
            URL resourceURL = jarConn.getJarFileURL();
            URLConnection resourceConn = resourceURL.openConnection();
            resourceConn.setUseCaches(false);
            return new NonClosingJarInputStream(resourceConn.getInputStream());
        }
        return new NonClosingJarInputStream(urlConnection.getInputStream());
    }
}
